==> knative-model-6.8.0-sources.jar: io/fabric8/knative/internal/pkg/apis/duck/v1beta1/BindingSpecFluent.java <==
package io.fabric8.knative.internal.pkg.apis.duck.v1beta1;

import io.fabric8.knative.internal.pkg.tracker.Reference;
import io.fabric8.knative.internal.pkg.tracker.ReferenceFluent;
import java.lang.SuppressWarnings;
import io.fabric8.knative.internal.pkg.tracker.ReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class BindingSpecFluent<A extends BindingSpecFluent<A>> extends BaseFluent<A>{
  public BindingSpecFluent() {
  }
  public BindingSpecFluent(BindingSpec instance) {
    instance = (instance != null ? instance : new BindingSpec());

    if (instance != null) {
      this.withSubject(instance.getSubject());
      this.withSubject(instance.getSubject());
    }
  }
  private ReferenceBuilder subject;
  public Reference buildSubject() {
    return this.subject!=null ?this.subject.build():null;
  }
  public A withSubject(Reference subject) {
    _visitables.get("subject").remove(this.subject);
    if (subject!=null){ this.subject= new ReferenceBuilder(subject); _visitables.get("subject").add(this.subject);} else { this.subject = null; _visitables.get("subject").remove(this.subject); } return (A) this;
  }
  public boolean hasSubject() {
    return this.subject != null;
  }
  public SubjectNested<A> withNewSubject() {
    return new SubjectNested(null);
  }
  public SubjectNested<A> withNewSubjectLike(Reference item) {
    return new SubjectNested(item);
  }
  public SubjectNested<A> editSubject() {
    return withNewSubjectLike(java.util.Optional.ofNullable(buildSubject()).orElse(null));
  }
  public SubjectNested<A> editOrNewSubject() {
    return withNewSubjectLike(java.util.Optional.ofNullable(buildSubject()).orElse(new ReferenceBuilder().build()));
  }
  public SubjectNested<A> editOrNewSubjectLike(Reference item) {
    return withNewSubjectLike(java.util.Optional.ofNullable(buildSubject()).orElse(item));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BindingSpecFluent that = (BindingSpecFluent) o;
    if (!java.util.Objects.equals(subject, that.subject)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(subject,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (subject != null) { sb.append("subject:"); sb.append(subject); }
    sb.append("}");
    return sb.toString();
  }
  public class SubjectNested<N> extends ReferenceFluent<SubjectNested<N>> implements Nested<N>{
    SubjectNested(Reference item) {
      this.builder = new ReferenceBuilder(this, item);
    }
    ReferenceBuilder builder;
    public N and() {
      return (N) BindingSpecFluent.this.withSubject(builder.build());
    }
    public N endSubject() {
      return and();
    }
    
  }
  
}

==> knative-model-6.9.0-sources.jar: io/fabric8/knative/internal/pkg/apis/duck/v1beta1/BindingSpecFluent.java <==
package io.fabric8.knative.internal.pkg.apis.duck.v1beta1;

import io.fabric8.knative.internal.pkg.tracker.Reference;
import io.fabric8.knative.internal.pkg.tracker.ReferenceFluent;
import java.lang.SuppressWarnings;
import io.fabric8.knative.internal.pkg.tracker.ReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class BindingSpecFluent<A extends BindingSpecFluent<A>> extends BaseFluent<A>{
  public BindingSpecFluent() {
  }
  
  public BindingSpecFluent(BindingSpec instance) {
    this.copyInstance(instance);
  }
  private ReferenceBuilder subject;
  
  protected void copyInstance(BindingSpec instance) {
    instance = (instance != null ? instance : new BindingSpec());
  
    if (instance != null) {
        this.withSubject(instance.getSubject());
        this.withSubject(instance.getSubject());
      }
  }
  
  public Reference buildSubject() {
    return this.subject!=null ?this.subject.build():null;
  }
  
  public A withSubject(Reference subject) {
    _visitables.get("subject").remove(this.subject);
    if (subject!=null){ this.subject= new ReferenceBuilder(subject); _visitables.get("subject").add(this.subject);} else { this.subject = null; _visitables.get("subject").remove(this.subject); } return (A) this;
  }
  
  public boolean hasSubject() {
    return this.subject != null;
  }
  
  public SubjectNested<A> withNewSubject() {
    return new SubjectNested(null);
  }
  
  public SubjectNested<A> withNewSubjectLike(Reference item) {
    return new SubjectNested(item);
  }
  
  public SubjectNested<A> editSubject() {
    return withNewSubjectLike(java.util.Optional.ofNullable(buildSubject()).orElse(null));
  }
  
  public SubjectNested<A> editOrNewSubject() {
    return withNewSubjectLike(java.util.Optional.ofNullable(buildSubject()).orElse(new ReferenceBuilder().build()));
  }
  
  public SubjectNested<A> editOrNewSubjectLike(Reference item) {
    return withNewSubjectLike(java.util.Optional.ofNullable(buildSubject()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BindingSpecFluent that = (BindingSpecFluent) o;
    if (!java.util.Objects.equals(subject, that.subject)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(subject,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (subject != null) { sb.append("subject:"); sb.append(subject); }
    sb.append("}");
    return sb.toString();
  }
  public class SubjectNested<N> extends ReferenceFluent<SubjectNested<N>> implements Nested<N>{
    SubjectNested(Reference item) {
      this.builder = new ReferenceBuilder(this, item);
    }
    ReferenceBuilder builder;
    
    public N and() {
      return (N) BindingSpecFluent.this.withSubject(builder.build());
    }
    
    public N endSubject() {
      return and();
    }
    
  
  }

}
